# Nautilus Core

Nautilus Core is the backbone of the NautilusTrader platform, offering a set of
Rust libraries that provide the necessary foundation for creating event-driven
trading systems, backtesting strategies on historical data, and executing trades
in real-time. It is designed to be reliable, performant, modular, testable,
maintainable, and easily deployable, making it a powerful tool for quantitative
traders.

## License

The source code for NautilusTrader is available on GitHub under the [GNU Lesser General Public License v3.0](https://www.gnu.org/licenses/lgpl-3.0.en.html).
Contributions to the project are welcome and require the completion of a standard Contributor License Agreement (CLA).

---

NautilusTrader is developed and maintained by Nautech Systems, a technology
company specializing in the development of high-performance trading systems.
For more information, visit https://nautilustrader.io.

Copyright (C) 2015-2025 Nautech Systems Pty Ltd. All rights reserved.

![nautechsystems](https://github.com/nautechsystems/nautilus_trader/blob/develop/docs/_images/ns-logo.png?raw=true "nautechsystems")
<img src="https://github.com/nautechsystems/nautilus_trader/blob/develop/docs/_images/ferris.png" width="128">
